@@ -1,4 +1,4 @@
-DB_FILENAME = '../db.sqlite3'
+DB_FILENAME = 'db.sqlite3'
 
 SUPPORTED_TYPES = {'str': 'TEXT',
                    'int': 'INTEGER',
